@@ -5,6 +5,7 @@ use std::ops::Add;
 use crate::core::data_types::{DataType, Field, Schema};
 use crate::core::element::{BufferMutReader, BufferReader, BufferWriter, FnSchema, Record};
 use crate::core::function::{Context, NamedFunction, ReduceFunction};
+use crate::functions::column_locate::{ColumnLocate, ColumnLocateBuilder};
 use crate::functions::percentile::{get_percentile_capacity, PercentileWriter};
 
 pub fn count() -> AggregationDescriptor {
@@ -27,37 +28,6 @@ pub fn pct<T: ColumnLocateBuilder>(column: T, scale: &'static [f64]) -> Aggregat
     AggregationDescriptor::Pct(column.build(), scale)
 }
 
-#[derive(Clone, Debug)]
-pub enum ColumnLocate {
-    Index(usize),
-    Name(String),
-}
-
-impl ColumnLocate {
-    fn to_column<'a>(&self, schema: &'a Schema) -> (usize, &'a Field) {
-        match self {
-            Self::Index(index) => (*index, schema.field(*index)),
-            Self::Name(name) => schema.column_with_name(name.as_str()).unwrap(),
-        }
-    }
-}
-
-pub trait ColumnLocateBuilder {
-    fn build(&self) -> ColumnLocate;
-}
-
-impl ColumnLocateBuilder for usize {
-    fn build(&self) -> ColumnLocate {
-        ColumnLocate::Index(*self)
-    }
-}
-
-impl<'a> ColumnLocateBuilder for &'a str {
-    fn build(&self) -> ColumnLocate {
-        ColumnLocate::Name(self.to_string())
-    }
-}
-
 #[derive(Clone, Debug)]
 pub enum AggregationDescriptor {
     Count,
